Audio file metadata parsing.
Audio file metadata parsing.
(probe filename)Guess the codec label (e.g. "FLAC") from a filename's extension without opening the file. Returns nil for an unknown extension.
Guess the codec label (e.g. "FLAC") from a filename's extension without opening the file. Returns nil for an unknown extension.
(read path)Parse the metadata of the audio file at path.
Returns a map (keyword keys) with tag strings, :duration_ms, :bitrate, :sample_rate, a nested :replaygain map (including the raw Q7.24 :raw_* fields), and optional :album_art / :cuesheet locations. Throws on failure.
Parse the metadata of the audio file at `path`. Returns a map (keyword keys) with tag strings, :duration_ms, :bitrate, :sample_rate, a nested :replaygain map (including the raw Q7.24 :raw_* fields), and optional :album_art / :cuesheet locations. Throws on failure.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |