Play an audio file through the real output device.
Run: mise exec -- clojure -M:play [/path/to/audio]
Play an audio file through the real output device. Run: mise exec -- clojure -M:play [/path/to/audio]
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |