Clojure only.

rockbox.ffi.play

Play an audio file through the real output device.

Run: mise exec -- clojure -M:play [/path/to/audio]

Play an audio file through the real output device.

Run: mise exec -- clojure -M:play [/path/to/audio]
raw docstring

-mainclj

(-main & args)
source

cljdoc builds & hosts documentation for Clojure/Script libraries